@@ -14,7 +14,7 @@ use Data::Dumper;
 use vars qw/$NS/;
 
 
-our $VERSION = '0.095';
+our $VERSION = '0.19';
 
 # Some constants
 # TODO: This stuff should go somewhere else!
@@ -85,6 +85,24 @@ sub authlevel_extremes {
     return {'minlevel' => $minlevel, 'maxlevel' => $maxlevel};
 }
 
+
+sub _sanatize_username {
+    my $tmp = lc shift;
+    $tmp =~ tr/a-z/_/cs;
+    return $tmp;
+}
+
+sub _exists_check {
+  my $username = shift;
+  my $user = AxKit::App::TABOO::Data::User->new();
+  if (($username =~ m/comment|thread|all|respond|edit/) || ($user->load_name($username)) || ($username ne _sanatize_username($username))) {
+    return 1;
+  } else {
+    return 0;
+  }
+}
+
+
 package AxKit::App::TABOO::XSP::User::Handlers;
 
 
@@ -160,7 +178,11 @@ EOC
 
 =head2 C<E<lt>new-user/E<gt>>
 
-This tag will store the contents of an Apache::Request object in the data store, but perform little checks on the data given. The only thing it checks is that hte username isn't in use and allready. Then, if the authlevel is different from 1, it is checked if the logged in user is privileged to set the authlevel.   
+This tag will store the contents of an Apache::Request object in the
+data store, but perform little checks on the data given. The only
+thing it checks is that the username isn't in use and allready. Then,
+if the authlevel is different from 1, it is checked if the logged in
+user is privileged to set the authlevel.
 
 =cut
 
@@ -303,8 +325,7 @@ sub exists : attribOrChild(username) {
 
 sub exists___true__open {
 return << 'EOC';
-    my $user = AxKit::App::TABOO::Data::User->new();
-    if (($attr_username =~ m/comment|thread|all|respond|edit/) || ($user->load_name($attr_username))) {
+    if (AxKit::App::TABOO::XSP::User::_exists_check($attr_username)) {
 EOC
 }
 
@@ -315,8 +336,7 @@ sub exists___true {
 
 sub exists___false__open {
 return << 'EOC';
-    my $user = AxKit::App::TABOO::Data::User->new();
-    unless (($attr_username =~ m/comment|thread|all|respond|edit/) || ($user->load_name($attr_username))) {
+    unless (AxKit::App::TABOO::XSP::User::_exists_check($attr_username)) {
 EOC
 }
 
